# Rundeck Executions Cleanup

Python CLI to remove old Rundeck executions and log files

This project was based on the [RundeckLogfileCleanup](https://github.com/phwitservices/RundeckLogfileCleanup) repository.
